@@ -6,6 +6,7 @@
 #ifdef INTEROP_DEBUGGING
 
 #include "debugger/interop_ptrace_helpers.h"
+#include "debugger/interop_singlestep_helpers.h"
 #include <cstdint>
 #include <vector>
 
@@ -15,18 +16,7 @@ namespace InteropDebugging
 {
 
 #if DEBUGGER_UNIX_ARM
-struct sw_singlestep_brk_t
-{
-    std::uintptr_t bpAddr = 0;
-    word_t restoreData = 0;
 
-    sw_singlestep_brk_t(std::uintptr_t addr, word_t data) :
-        bpAddr(addr),
-        restoreData(data)
-    {}
-};
-
-bool ARM32_RemoveSoftwareSingleStepBreakpoints(pid_t pid, std::vector<sw_singlestep_brk_t> &swSingleStepBreakpoints);
 bool ARM32_DoSoftwareSingleStep(pid_t pid, std::vector<sw_singlestep_brk_t> &swSingleStepBreakpoints);
 
 #endif // DEBUGGER_UNIX_ARM
