@@ -7,6 +7,7 @@
 #include "debugger/interop_mem_helpers.h"
 #include "debugger/interop_ptrace_helpers.h"
 #include "debugger/interop_arm32_singlestep_helpers.h"
+#include "debugger/interop_riscv64_singlestep_helpers.h"
 
 #ifdef DEBUGGER_FOR_TIZEN
 // Tizen 5.0/5.5 build fix.
@@ -78,11 +79,15 @@ InteropDebugger::InteropDebugger(IProtocol *pProtocol_,
     InteropDebuggerHelpers(pProtocol_, sharedBreakpoints, sharedEvalWaiter)
 {}
 
-#if DEBUGGER_UNIX_ARM
+#if DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
 // NOTE caller must care about m_waitpidMutex.
 static bool DoSoftwareSingleStep(pid_t pid, std::unordered_map<pid_t, thread_status_t> &TIDs, std::vector<sw_singlestep_brk_t> &swSingleStepBreakpoints)
 {
+#if DEBUGGER_UNIX_ARM
     if (!ARM32_DoSoftwareSingleStep(pid, swSingleStepBreakpoints))
+#else
+    if (!RISCV64_DoSoftwareSingleStep(pid, swSingleStepBreakpoints))
+#endif
     {
         LOGE("Software singlestep initialization error.\n");
         return false;
@@ -90,7 +95,8 @@ static bool DoSoftwareSingleStep(pid_t pid, std::unordered_map<pid_t, thread_sta
 
     if (async_ptrace(PTRACE_CONT, pid, nullptr, nullptr) == -1)
     {
-        LOGW("Ptrace cont error: %s", strerror(errno));
+        char buf[1024];
+        LOGW("Ptrace cont error: %s", ErrGetStr(errno, buf, sizeof(buf)));
         return false;
     }
     else
@@ -110,8 +116,9 @@ static bool DetectBrkForSoftwareSingleStep(pid_t pid, std::unordered_map<pid_t,
     iov.iov_len = sizeof(user_regs_struct);
     if (async_ptrace(PTRACE_GETREGSET, pid, (void*)NT_PRSTATUS, &iov) == -1)
     {
-        LOGW("Ptrace getregset error: %s\n", strerror(errno));
-        ARM32_RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
+        char buf[1024];
+        LOGW("Ptrace getregset error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+        RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
         return false;
     }
 
@@ -121,15 +128,15 @@ static bool DetectBrkForSoftwareSingleStep(pid_t pid, std::unordered_map<pid_t,
     {
         if (entry.bpAddr == brkAddr)
         {
-            // Note, we don't call SetPrevBrkPC() + ptrace(PTRACE_SETREGSET) here, since arm32 don't need this for sure.
+            // Note, we don't call SetPrevBrkPC() + ptrace(PTRACE_SETREGSET) here, since arm32/riscv64 don't need this for sure.
             TIDs[pid].stop_signal = 0;
             break;
         }
     }
 
-    return ARM32_RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
+    return RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
 };
-#endif // DEBUGGER_UNIX_ARM
+#endif // DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
 
 // NOTE caller must care about m_waitpidMutex.
 bool InteropDebuggerBase::SingleStepOnBrk(pid_t pid, std::uintptr_t addr)
@@ -142,36 +149,38 @@ bool InteropDebuggerBase::SingleStepOnBrk(pid_t pid, std::uintptr_t addr)
     // Another case is signal that landed on stopped thread. For example SIGKILL from user or SIGILL
     // due to wrong instruction that was covered by breakpoint opcode and now executed on single step.
 
-#if DEBUGGER_UNIX_ARM
+#if DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
     std::vector<sw_singlestep_brk_t> swSingleStepBreakpoints;
 
     if (!m_HWSingleStepSupported)
     {
         if (!DoSoftwareSingleStep(pid, m_TIDs, swSingleStepBreakpoints))
         {
-            ARM32_RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
+            RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
             return false;
         }
     }
     else
-#endif // DEBUGGER_UNIX_ARM
+#endif // DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
     {
         if (async_ptrace(PTRACE_SINGLESTEP, pid, nullptr, nullptr) == -1)
         {
+// ARM32 only here, since for RISCV64 `m_HWSingleStepSupported` by default is `false`, that mean this code will be never executed for this arch.
 #if DEBUGGER_UNIX_ARM
             if (errno == EIO)
             {
                 m_HWSingleStepSupported = false;
                 if (!DoSoftwareSingleStep(pid, m_TIDs, swSingleStepBreakpoints))
                 {
-                    ARM32_RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
+                    RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
                     return false;
                 }
             }
             else
 #endif // DEBUGGER_UNIX_ARM
             {
-                LOGE("Ptrace singlestep error: %s\n", strerror(errno));
+                char buf[1024];
+                LOGE("Ptrace singlestep error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
                 return false;
             }
         }
@@ -187,10 +196,10 @@ bool InteropDebuggerBase::SingleStepOnBrk(pid_t pid, std::uintptr_t addr)
     // Check that we still have this thread alive.
     if (m_TIDs.find(pid) == m_TIDs.end())
     {
-#if DEBUGGER_UNIX_ARM
+#if DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
         if (!m_HWSingleStepSupported)
-            ARM32_RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
-#endif // DEBUGGER_UNIX_ARM
+            RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
+#endif // DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
         return false;
     }
 
@@ -200,11 +209,12 @@ bool InteropDebuggerBase::SingleStepOnBrk(pid_t pid, std::uintptr_t addr)
         siginfo_t ptrace_info;
         if (async_ptrace(PTRACE_GETSIGINFO, pid, nullptr, &ptrace_info) == -1)
         {
-            LOGW("Ptrace getsiginfo error: %s\n", strerror(errno));
-#if DEBUGGER_UNIX_ARM
+            char buf[1024];
+            LOGW("Ptrace getsiginfo error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+#if DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
             if (!m_HWSingleStepSupported)
-                ARM32_RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
-#endif // DEBUGGER_UNIX_ARM
+                RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints);
+#endif // DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
             return false;
         }
 
@@ -212,14 +222,14 @@ bool InteropDebuggerBase::SingleStepOnBrk(pid_t pid, std::uintptr_t addr)
         {
         case SI_KERNEL:
         case TRAP_BRKPT:
-#if DEBUGGER_UNIX_ARM
+#if DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
             if (!m_HWSingleStepSupported)
             {
                 bool parseSucceeded = DetectBrkForSoftwareSingleStep(pid, m_TIDs, swSingleStepBreakpoints);
                 if (!parseSucceeded || m_TIDs[pid].stop_signal == 0)
                     return parseSucceeded;
             }
-#endif // DEBUGGER_UNIX_ARM
+#endif // DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
             // Care about `__builtin_debugtrap()` in user code.
             m_TIDs[pid].stat = thread_stat_e::stopped_signal_event_detected;
             m_TIDs[pid].stop_event_data.signal = "SIGTRAP";
@@ -232,17 +242,18 @@ bool InteropDebuggerBase::SingleStepOnBrk(pid_t pid, std::uintptr_t addr)
         }
     }
 
-#if DEBUGGER_UNIX_ARM
-    if (!m_HWSingleStepSupported && !ARM32_RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints))
+#if DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
+    if (!m_HWSingleStepSupported && !RemoveSoftwareSingleStepBreakpoints(pid, swSingleStepBreakpoints))
         return false;
-#endif // DEBUGGER_UNIX_ARM
+#endif // DEBUGGER_UNIX_ARM || DEBUGGER_UNIX_RISCV64
 
     if (m_TIDs[pid].stop_signal == SIGILL)
     {
         siginfo_t ptrace_info;
         if (async_ptrace(PTRACE_GETSIGINFO, pid, nullptr, &ptrace_info) == -1)
         {
-            LOGW("Ptrace getsiginfo error: %s\n", strerror(errno));
+            char buf[1024];
+            LOGW("Ptrace getsiginfo error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
             return false;
         }
 
@@ -331,7 +342,10 @@ void InteropDebuggerBase::WaitThreadStop(pid_t stoppedPid, std::vector<pid_t> *s
             siginfo_t siginfo;
             bool sendByItself = false;
             if (async_ptrace(PTRACE_GETSIGINFO, pid, nullptr, &siginfo) == -1)
-                LOGW("Ptrace getsiginfo error: %s\n", strerror(errno));
+            {
+                char buf[1024];
+                LOGW("Ptrace getsiginfo error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+            }
             else
                 sendByItself = (siginfo.si_pid == m_TGID);
 
@@ -370,7 +384,8 @@ void InteropDebuggerHelpers::StopAndDetach(pid_t tgid)
         iov.iov_len = sizeof(user_regs_struct);
         if (async_ptrace(PTRACE_GETREGSET, entry.first, (void*)NT_PRSTATUS, &iov) == -1)
         {
-            LOGW("Ptrace getregset error: %s\n", strerror(errno));
+            char buf[1024];
+            LOGW("Ptrace getregset error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
             continue; // Will hope, this thread didn't stopped at breakpoint.
         }
 
@@ -387,7 +402,10 @@ void InteropDebuggerHelpers::StopAndDetach(pid_t tgid)
     for (const auto &tid : m_TIDs)
     {
         if (async_ptrace(PTRACE_DETACH, tid.first, nullptr, (void*)((word_t)tid.second.stop_signal)) == -1)
-            LOGW("Ptrace detach error: %s\n", strerror(errno));
+        {
+            char buf[1024];
+            LOGW("Ptrace detach error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+        }
     }
 
     m_TIDs.clear();
@@ -403,7 +421,8 @@ static void StopAllRunningThreads(const std::unordered_map<pid_t, thread_status_
         if (tid.second.stat == thread_stat_e::running &&
             async_ptrace(PTRACE_INTERRUPT, tid.first, nullptr, nullptr) == -1)
         {
-            LOGW("Ptrace interrupt error: %s\n", strerror(errno));
+            char buf[1024];
+            LOGW("Ptrace interrupt error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
         }
     }
 }
@@ -458,7 +477,8 @@ static HRESULT SeizeAndInterruptAllThreads(std::unordered_map<pid_t, thread_stat
     if (!dir)
     {
         error_n = errno;
-        LOGE("opendir: %s\n", strerror(errno));
+        char buf[1024];
+        LOGE("opendir: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
         return E_FAIL;
     }
 
@@ -484,7 +504,8 @@ static HRESULT SeizeAndInterruptAllThreads(std::unordered_map<pid_t, thread_stat
         if (async_ptrace(PTRACE_SEIZE, tid, nullptr, (void*)options) == -1)
         {
             error_n = errno;
-            LOGE("Ptrace seize error: %s\n", strerror(errno));
+            char buf[1024];
+            LOGE("Ptrace seize error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
             closedir(dir);
             return E_FAIL;
         }
@@ -494,7 +515,8 @@ static HRESULT SeizeAndInterruptAllThreads(std::unordered_map<pid_t, thread_stat
 
         if (async_ptrace(PTRACE_INTERRUPT, tid, nullptr, nullptr) == -1)
         {
-            LOGE("Ptrace interrupt error: %s\n", strerror(errno));
+            char buf[1024];
+            LOGE("Ptrace interrupt error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
             closedir(dir);
             exit(EXIT_FAILURE); // Fatal error, seized but failed on interrupt.
         }
@@ -502,13 +524,15 @@ static HRESULT SeizeAndInterruptAllThreads(std::unordered_map<pid_t, thread_stat
     if (errno)
     {
         error_n = errno;
-        LOGE("readdir: %s\n", strerror(errno));
+        char buf[1024];
+        LOGE("readdir: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
         closedir(dir);
         return E_FAIL;
     }
     if (closedir(dir))
     {
-        LOGW("closedir: %s\n", strerror(errno));
+        char buf[1024];
+        LOGW("closedir: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
     }
 
     return S_OK;
@@ -562,7 +586,8 @@ static bool AddSignalEventForUserCode(pid_t pid, InteropLibraries *pInteropLibra
     iov.iov_len = sizeof(user_regs_struct);
     if (async_ptrace(PTRACE_GETREGSET, pid, (void*)NT_PRSTATUS, &iov) == -1)
     {
-        LOGW("Ptrace getregset error: %s\n", strerror(errno));
+        char buf[1024];
+        LOGW("Ptrace getregset error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
         return false;
     }
 
@@ -585,7 +610,8 @@ static bool AddSignalEventForCallerInUserCode(pid_t pid, pid_t TGID, InteropLibr
     memset(&siginfo, 0, sizeof(siginfo_t));
     if (async_ptrace(PTRACE_GETSIGINFO, pid, nullptr, &siginfo) == -1)
     {
-        LOGW("Ptrace getsiginfo error: %s\n", strerror(errno));
+        char buf[1024];
+        LOGW("Ptrace getsiginfo error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
         return false;
     }
     if (siginfo.si_pid != TGID)
@@ -608,17 +634,45 @@ static bool AddSignalEventForCallerInUserCode(pid_t pid, pid_t TGID, InteropLibr
         // (?) check that top frame is user code / not CoreCLR (but skip frames with "system" libs like libc, libpthread, ...)
 
         // (?) check lib + method name for first frame:
-        // raise(SIGTRAP)                                   -> libpthread-2.31.so` raise()
-        // kill(syscall(SYS_gettid), SIGTRAP)               -> libc-2.31.so` kill()
-        // tgkill(getpid(), syscall(SYS_gettid), SIGTRAP)   -> libc-2.31.so` tgkill()
-        // syscall(SYS_tkill, syscall(SYS_gettid), SIGTRAP) -> libc-2.31.so` syscall()
+        // raise(SIGTRAP)                                   -> libpthread.so`raise()
+        // kill(syscall(SYS_gettid), SIGTRAP)               -> libc.so`kill()
+        // tgkill(getpid(), syscall(SYS_gettid), SIGTRAP)   -> libc.so`tgkill()
+        // syscall(SYS_tkill, syscall(SYS_gettid), SIGTRAP) -> libc.so`syscall()
 
+#if DEBUGGER_UNIX_RISCV64
+        // Note, in case of RISCV64:
+        //      raise(SIGTRAP): libc.so`raise() => libc.so`gsignal() => user code
+        if (frameCount == 1)
+        {
+            breakAddr = addr;
+            return true;
+        }
+        else
+        {
+            std::string libLoadName;
+            std::string procName;
+            if (pInteropLibraries->FindDataForNotClrAddr(addr, libLoadName, procName))
+            {
+                if (libLoadName == "libc.so")
+                {
+                    return true;
+                }
+                else
+                {
+                    isUserDebuggingCode = pInteropLibraries->IsUserDebuggingCode(addr);
+                    return false;
+                }
+            }
+            return false;
+        }
+#else
         if (frameCount == 1)
             breakAddr = addr;
         else
             isUserDebuggingCode = pInteropLibraries->IsUserDebuggingCode(addr);
 
         return frameCount < 2;
+#endif
     });
     if (!isUserDebuggingCode)
         return false;
@@ -635,7 +689,8 @@ void InteropDebuggerSignals::Parse_SIGILL(pid_t pid)
     siginfo_t ptrace_info;
     if (async_ptrace(PTRACE_GETSIGINFO, pid, nullptr, &ptrace_info) == -1)
     {
-        LOGW("Ptrace getsiginfo error: %s\n", strerror(errno));
+        char buf[1024];
+        LOGW("Ptrace getsiginfo error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
     }
     else
     {
@@ -665,7 +720,10 @@ void InteropDebuggerSignals::Parse_SIGTRAP__PTRACE_EVENT_EXEC(pid_t pid)
     }
 
     if (async_ptrace(PTRACE_DETACH, pid, nullptr, nullptr) == -1)
-        LOGW("Ptrace detach at exec error: %s\n", strerror(errno));
+    {
+        char buf[1024];
+        LOGW("Ptrace detach at exec error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+    }
     else
         m_TIDs.erase(pid);
 }
@@ -675,7 +733,8 @@ void InteropDebuggerSignals::Parse_SIGTRAP__NOT_PTRACE_EVENT(pid_t pid)
     siginfo_t ptrace_info;
     if (async_ptrace(PTRACE_GETSIGINFO, pid, nullptr, &ptrace_info) == -1)
     {
-        LOGW("Ptrace getsiginfo error: %s\n", strerror(errno));
+        char buf[1024];
+        LOGW("Ptrace getsiginfo error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
     }
     else
     {
@@ -690,7 +749,10 @@ void InteropDebuggerSignals::Parse_SIGTRAP__NOT_PTRACE_EVENT(pid_t pid)
                 iov.iov_base = &regs;
                 iov.iov_len = sizeof(user_regs_struct);
                 if (async_ptrace(PTRACE_GETREGSET, pid, (void*)NT_PRSTATUS, &iov) == -1)
-                    LOGW("Ptrace getregset error: %s\n", strerror(errno));
+                {
+                    char buf[1024];
+                    LOGW("Ptrace getregset error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+                }
 
                 std::uintptr_t brkAddr = GetBrkAddrByPC(regs);
 
@@ -831,7 +893,10 @@ void InteropDebuggerBase::ParseThreadsChanges()
             continue;
 
         if (async_ptrace(PTRACE_CONT, pid, nullptr, (void*)((word_t)m_TIDs[pid].stop_signal)) == -1)
-            LOGW("Ptrace cont error: %s", strerror(errno));
+        {
+            char buf[1024];
+            LOGW("Ptrace cont error: %s", ErrGetStr(errno, buf, sizeof(buf)));
+        }
         else
         {
             m_TIDs[pid].stat = thread_stat_e::running;
@@ -885,7 +950,7 @@ void InteropDebuggerBase::CallbackEventWorker()
                     }
                     break;
                 default:
-                    LOGW("This event type is not stop event: %d", entry.stat);
+                    LOGW("This event type is not stop event: %d", (int)entry.stat);
                     break;
                 }
             }
@@ -922,7 +987,7 @@ void InteropDebuggerBase::ParseThreadsEvents()
             m_callbackEvents.emplace_back(pid, m_TIDs[pid].stat, m_TIDs[pid].stop_event_data);
             break;
         default:
-            LOGW("This event type is not stop event: %d", m_TIDs[pid].stat);
+            LOGW("This event type is not stop event: %d", (int)m_TIDs[pid].stat);
             break;
         }
     }
@@ -994,7 +1059,10 @@ static void StopAllManagedThreads(std::unordered_map<pid_t, thread_status_t> &TI
             continue;
 
         if (async_ptrace(PTRACE_INTERRUPT, managedThread.first, nullptr, nullptr) == -1)
-            LOGW("Ptrace interrupt error: %s\n", strerror(errno));
+        {
+            char buf[1024];
+            LOGW("Ptrace interrupt error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+        }
         else
             stoppedManagedTreads.emplace_back(managedThread.first);
     }
@@ -1181,7 +1249,8 @@ void InteropDebuggerBase::WaitpidWorker()
 
         if (pid == -1)
         {
-            LOGE("Waitpid error: %s\n", strerror(errno));
+            char buf[1024];
+            LOGE("Waitpid error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
             break;
         }
 
@@ -1244,7 +1313,10 @@ void InteropDebuggerBase::WaitpidWorker()
             siginfo_t siginfo;
             bool sendByItself = false;
             if (async_ptrace(PTRACE_GETSIGINFO, pid, nullptr, &siginfo) == -1)
-                LOGW("Ptrace getsiginfo error: %s\n", strerror(errno));
+            {
+                char buf[1024];
+                LOGW("Ptrace getsiginfo error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+            }
             else
                 sendByItself = (siginfo.si_pid == m_TGID);
 
@@ -1260,7 +1332,10 @@ void InteropDebuggerBase::WaitpidWorker()
                     injectTIDs.emplace(std::make_pair(pid, injectSignalResetCountdown));
 
                 if (async_ptrace(PTRACE_CONT, pid, nullptr, (void*)((word_t)stop_signal)) == -1)
-                    LOGW("Ptrace cont error: %s", strerror(errno));
+                {
+                    char buf[1024];
+                    LOGW("Ptrace cont error: %s", ErrGetStr(errno, buf, sizeof(buf)));
+                }
                 // No need change `m_TIDs[pid].stat` and `m_TIDs[pid].stop_signal` here.
                 continue;
             }
@@ -1367,7 +1442,8 @@ void InteropDebuggerHelpers::BrkFixAllThreads(std::uintptr_t checkAddr)
         iov.iov_len = sizeof(user_regs_struct);
         if (async_ptrace(PTRACE_GETREGSET, entry.first, (void*)NT_PRSTATUS, &iov) == -1)
         {
-            LOGW("Ptrace getregset error: %s\n", strerror(errno));
+            char buf[1024];
+            LOGW("Ptrace getregset error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
             continue; // Will hope, this thread didn't stopped at breakpoint.
         }
 
@@ -1516,7 +1592,40 @@ static std::array<unw_word_t, UNW_REG_LAST + 1> *InitContextRegs(std::array<unw_
     contextRegs[UNW_AARCH64_SP]       = context->Sp;
     contextRegs[UNW_AARCH64_PC]       = context->Pc;
     contextRegs[UNW_AARCH64_PSTATE]   = context->Cpsr;
-
+#elif defined(UNW_TARGET_RISCV)
+    contextRegs[UNW_RISCV_X0]       = context->R0;
+    contextRegs[UNW_RISCV_X1]       = context->Ra;
+    contextRegs[UNW_RISCV_X2]       = context->Sp;
+    contextRegs[UNW_RISCV_X3]       = context->Gp;
+    contextRegs[UNW_RISCV_X4]       = context->Tp;
+    contextRegs[UNW_RISCV_X5]       = context->T0;
+    contextRegs[UNW_RISCV_X6]       = context->T1;
+    contextRegs[UNW_RISCV_X7]       = context->T2;
+    contextRegs[UNW_RISCV_X8]       = context->Fp;
+    contextRegs[UNW_RISCV_X9]       = context->S1;
+    contextRegs[UNW_RISCV_X10]      = context->A0;
+    contextRegs[UNW_RISCV_X11]      = context->A1;
+    contextRegs[UNW_RISCV_X12]      = context->A2;
+    contextRegs[UNW_RISCV_X13]      = context->A3;
+    contextRegs[UNW_RISCV_X14]      = context->A4;
+    contextRegs[UNW_RISCV_X15]      = context->A5;
+    contextRegs[UNW_RISCV_X16]      = context->A6;
+    contextRegs[UNW_RISCV_X17]      = context->A7;
+    contextRegs[UNW_RISCV_X18]      = context->S2;
+    contextRegs[UNW_RISCV_X19]      = context->S3;
+    contextRegs[UNW_RISCV_X20]      = context->S4;
+    contextRegs[UNW_RISCV_X21]      = context->S5;
+    contextRegs[UNW_RISCV_X22]      = context->S6;
+    contextRegs[UNW_RISCV_X23]      = context->S7;
+    contextRegs[UNW_RISCV_X24]      = context->S8;
+    contextRegs[UNW_RISCV_X25]      = context->S9;
+    contextRegs[UNW_RISCV_X26]      = context->S10;
+    contextRegs[UNW_RISCV_X27]      = context->S11;
+    contextRegs[UNW_RISCV_X28]      = context->T3;
+    contextRegs[UNW_RISCV_X29]      = context->T4;
+    contextRegs[UNW_RISCV_X30]      = context->T5;
+    contextRegs[UNW_RISCV_X31]      = context->T6;
+    contextRegs[UNW_RISCV_PC]       = context->Pc;
 #else
 #error "Unsupported platform"
 #endif
@@ -1538,7 +1647,10 @@ HRESULT InteropDebugger::UnwindNativeFrames(pid_t pid, bool firstFrame, std::uin
     if (tid->second.stat == thread_stat_e::running)
     {
         if (async_ptrace(PTRACE_INTERRUPT, pid, nullptr, nullptr) == -1)
-            LOGW("Ptrace interrupt error: %s\n", strerror(errno));
+        {
+            char buf[1024];
+            LOGW("Ptrace interrupt error: %s\n", ErrGetStr(errno, buf, sizeof(buf)));
+        }
         else
         {
             WaitThreadStop(pid);
